<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-dump?lang_cible=fr_tu
// ** ne pas modifier le fichier **

return [

	// D
	'dump_description' => 'Sauvegarde de la base en SQLite et restauration',
	'dump_slogan' => 'Sauvegarde et restauration de la base SPIP',
];
